import pkg_resources

from alphaui.blocks import Blocks, Column, Row, Tab
from alphaui.flagging import (
    CSVLogger,
    FlaggingCallback,
    HuggingFaceDatasetSaver,
    SimpleCSVLogger,
)
from alphaui.interface import Interface, close_all, reset_all
from alphaui.mix import Parallel, Series
from alphaui.routes import get_state, set_state
from alphaui.static import Button, Markdown

# current_pkg_version = pkg_resources.require("gradio")[0].version
# __version__ = current_pkg_version



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
    name="alphaui",
    version="0.4.2",
    include_package_data=True,
    description="Python library for easily interacting with trained machine learning models",
    packages=["alphaui"],
    license="Apache License 2.0",
    keywords=["machine learning", "visualization", "reproducibility"],
    install_requires=[
        "analytics-python",
        "aiohttp",
        "fastapi",
        "ffmpy",
        "markdown-it-py[linkify,plugins]",
        "matplotlib",
        "numpy",
        "orjson",
        "pandas",
        "paramiko",
        "pillow",
        "pycryptodome",
        "python-multipart",
        "pydub",
        "requests",
        "uvicorn",
    ],
)
